/*
 * Copyright (c) 2015 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/*global define, tau, document, setTimeout*/

/**
 * Menu helper module.
 * Initializes a menu list for pages.
 */
define({
    name: 'helpers/uimenu',
    def: function uiMenu() {
        'use strict';

        /**
         * Binds click events on the menu buttons.
         * @param {HTMLElement} page
         */
        function bindOptionButtonsEvents(page) {
            var buttons = page.getElementsByClassName('option-button'),
                length = buttons.length,
                i = 0;

            function onClick() {
                tau.closePopup();
            }

            for (i = 0; i < length; i += 1) {
                buttons[i].addEventListener('click', onClick);
            }
        }

        /**
         * Creates menu widgets and returns an object that provides methods for
         * them.
         *
         * @param {string} pageId
         * @param {string} popupId
         * @returns {object}
         */
        function createUiMenu(pageId, popupId) {
            var page = document.getElementById(pageId),
                handler = page.querySelector('.ui-more'),
                selectorEl = page.getElementsByClassName('selector')[0],
                selector = null;

            function onSelectorClick() {
                selector.destroy();
                selectorEl.removeEventListener('click', onSelectorClick);
                tau.closePopup();
            }

            if (tau.support.shape.circle) {
                handler.addEventListener('click', function onClick() {
                    tau.openPopup('#' + popupId + '-circle');
                    selector = tau.widget.Selector(selectorEl);
                    selectorEl.addEventListener('click', onSelectorClick);
                });
            } else {
                handler.addEventListener('click', function onClick() {
                    tau.openPopup('#' + popupId);
                });
            }
            bindOptionButtonsEvents(page);

            return {
                /**
                 * Binds click event handler with menu button.
                 * @param {string} buttonClass
                 * @param {function} onClick
                 */
                bindClickEvent: function bindClickEvent(buttonClass, onClick) {
                    var buttons = page.getElementsByClassName(buttonClass),
                        length = buttons.length,
                        i = 0;

                    function clickHandler(event) {
                        setTimeout(function fn() {
                            onClick(event);
                        }, 100);
                    }

                    for (i = 0; i < length; i += 1) {
                        buttons[i].addEventListener('click', clickHandler);
                    }
                }
            };
        }

        return {
            createUiMenu: createUiMenu
        };
    }
});
